/*global ajaxurl, ddwcwm_users_export_params */
;(function ( $, window ) {
	/**
	 * usersExportForm handles the export process.
	 */
	var usersExportForm = function( $form ) {
		this.$form = $form;
		this.xhr   = false;

		// Initial state.
		this.$form.find('.woocommerce-exporter-progress').val( 0 );

		// Methods.
		this.processStep = this.processStep.bind( this );

		// Events.
		$form.on( 'submit', { usersExportForm: this }, this.onSubmit );
	};

	/**
	 * Handle export form submission.
	 */
	usersExportForm.prototype.onSubmit = function( event ) {
		event.preventDefault();

		var currentDate    = new Date(),
			day            = currentDate.getDate(),
			month          = currentDate.getMonth() + 1,
			year           = currentDate.getFullYear(),
			timestamp      = currentDate.getTime(),
			filename       = 'ddwcwm-users-export-' + day + '-' + month + '-' + year + '-' + timestamp + '.csv';

		event.data.usersExportForm.$form.addClass( 'woocommerce-exporter__exporting' );
		event.data.usersExportForm.$form.find('.woocommerce-exporter-progress').val( 0 );
		event.data.usersExportForm.$form.find('.woocommerce-exporter-button').prop( 'disabled', true );
		event.data.usersExportForm.processStep( 1, $( this ).serialize(), '', filename );
	};

	/**
	 * Process the current export step.
	 */
	usersExportForm.prototype.processStep = function( step, data, columns, filename ) {
		var $this         = this,
			selected_columns = $( '.woocommerce-exporter-columns' ).val()

		$.ajax( {
			type: 'POST',
			url: ajaxurl,
			data: {
				form             : data,
				action           : 'ddwcwm_do_ajax_users_export',
				step             : step,
				columns          : columns,
				selected_columns : selected_columns,
				filename         : filename,
				security         : ddwcwm_users_export_params.export_nonce
			},
			dataType: 'json',
			success: function( response ) {
                console.log(response)
				if ( response.success ) {
					$this.$form.find('.woocommerce-exporter-progress').val( response.data.percentage );
					if ( 'done' === response.data.step ) {
						window.location = response.data.url;
						setTimeout( function() {
							$this.$form.removeClass( 'woocommerce-exporter__exporting' );
							$this.$form.find('.woocommerce-exporter-button').prop( 'disabled', false );
						}, 2000 );
					} else {
						$this.processStep( parseInt( response.data.step, 10 ), data, response.data.columns, filename );
					}
				}


			}
		} ).fail( function( response ) {
			window.console.log( response );
		} );
	};

	/**
	 * Function to call usersExportForm on jquery selector.
	 */
	$.fn.ddwcwm_users_export_form = function() {
		new usersExportForm( this );
		return this;
	};

	$( '.woocommerce-exporter' ).ddwcwm_users_export_form();

})( jQuery, window );
