<?php
/**
 * Plugin Name: WooCommerce Wallet Management
 * Description: WooCommerce Wallet Management module allows customers to use virtual money on the store with lots of other features like send, request, or withdraw wallet money.
 * version: 2.5.0
 * Plugin URI: https://www.persianscript.ir
 * Author: پرشین اسکریپت
 * Author URI: https://www.persianscript.ir
 * Domain Path: /i18n
 * Text Domain: ddwc-wallet-management
 * WC requires at least: 5.0.0
 * WC tested up to: 6.7.x
 * WP requires at least: 5.0.0
 * WP tested up to: 6.0.x
 *
 * @package WooCommerce Wallet Management
 */

use DDWCWalletManagement\Includes;

// DDWCWM: DevDiggers WooCommerce Wallet Management.
defined( 'ABSPATH' ) || exit();

// Define Constants.
defined( 'DDWCWM_PLUGIN_FILE' ) || define( 'DDWCWM_PLUGIN_FILE', plugin_dir_path( __FILE__ ) );
defined( 'DDWCWM_PLUGIN_URL' ) || define( 'DDWCWM_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
defined( 'DDWCWM_SCRIPT_VERSION' ) || define( 'DDWCWM_SCRIPT_VERSION', '1.0.3' );

if ( ! function_exists( 'ddwcwm_includes' ) ) {
	/**
	 * Includes function
	 *
	 * @return void
	 */
	function ddwcwm_includes() {

		load_plugin_textdomain( 'ddwc-wallet-management', false, basename( dirname( __FILE__ ) ) . '/i18n' );

		if ( ! class_exists( 'WooCommerce' ) ) {
			add_action( 'admin_notices', function () {
				?>
				<div class="error">
					<p><?php echo sprintf( esc_html__( 'WooCommerce Wallet Management is enabled but not effective. It requires %sWooCommerce Plugin%s in order to use its functionalities.', 'ddwc-wallet-management' ), '<a href="' . esc_url( '//wordpress.org/plugins/woocommerce/' ) . '" target="_blank">', '</a>' ); ?></p>
				</div>
				<?php
			} );
		} else {
			require_once DDWCWM_PLUGIN_FILE . 'autoload/autoload.php';
			new Includes\DDWCWM_File_Handler();
		}

	}

	add_action( 'plugins_loaded', 'ddwcwm_includes' );
}

if ( ! function_exists( 'ddwcwm_plugin_settings_link' ) ) {

	/**
	 * Plugin settings link
	 *
	 * @param array $links Links Array.
	 * @return array $links
	 */
	function ddwcwm_plugin_settings_link( $links ) {
		ob_start();
		?>
		<a href="<?php echo esc_url( admin_url( 'admin.php?page=ddwcwm-configuration' ) ); ?>"><?php esc_html_e( 'Configuration', 'ddwc-wallet-management' ); ?></a>
		<?php
		array_unshift( $links, ob_get_contents() );
		ob_end_clean();
		return $links;
	}

	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'ddwcwm_plugin_settings_link' );

	/**
	 * Plugin Doc link
	 *
	 * @param array  $links Links.
	 * @param string $file File name.
	 * @return array $links
	 */
	function ddwcwm_plugin_row_meta( $links, $file ) {
		if ( plugin_basename( __FILE__ ) === $file ) {
			$row_meta = [
				'support' => '<a href="mailto:support@devdiggers.com" aria-label="' . esc_attr__( 'Support', 'ddwc-wallet-management' ) . '">' . esc_html__( 'Support', 'ddwc-wallet-management' ) . '</a>',
				'documentation' => '<a href="//devdiggers.com/woocommerce-wallet-management/" aria-label="' . esc_attr__( 'Documentation', 'ddwc-wallet-management' ) . '">' . esc_html__( 'Documentation', 'ddwc-wallet-management' ) . '</a>',
				'review' => '<a href="//codecanyon.net/downloads" target="_blank" title="' . esc_attr__( 'Review', 'ddwc-wallet-management' ) . '" aria-label="' . esc_attr__( 'Review', 'ddwc-wallet-management' ) . '"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 192 32" height="10"><path d="M16 26.534L6.111 32 8 20.422l-8-8.2 11.056-1.688L16 0l4.944 10.534L32 12.223l-8 8.2L25.889 32zm40 0L46.111 32 48 20.422l-8-8.2 11.056-1.688L56 0l4.944 10.534L72 12.223l-8 8.2L65.889 32zm40 0L86.111 32 88 20.422l-8-8.2 11.056-1.688L96 0l4.944 10.534L112 12.223l-8 8.2L105.889 32zm40 0L126.111 32 128 20.422l-8-8.2 11.056-1.688L136 0l4.944 10.534L152 12.223l-8 8.2L145.889 32zm40 0L166.111 32 168 20.422l-8-8.2 11.056-1.688L176 0l4.944 10.534L192 12.223l-8 8.2L185.889 32z" fill="#F5A623" fill-rule="evenodd"/></svg></a>',
			];
			$links = array_merge( $links, $row_meta );
		}

		return $links;
	}

	add_filter( 'plugin_row_meta', 'ddwcwm_plugin_row_meta', 10, 2 );

}

if ( ! function_exists( 'ddwcwm_create_schema' ) ) {
	require_once DDWCWM_PLUGIN_FILE . 'includes/install.php';
	register_activation_hook( __FILE__, [ 'DDWCWM_Install', 'ddwcwm_create_schema' ] );
}