<?php
/**
 * Handles users CSV export.
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Includes\Admin\Exporter;

use DDWCWalletManagement\Helper\Users\DDWCWM_Users_Helper;

defined( 'ABSPATH' ) || exit();

/**
 * Include dependencies.
 */
if ( ! class_exists( 'WC_CSV_Batch_Exporter', false ) ) {
	include_once WC_ABSPATH . 'includes/export/abstract-wc-csv-batch-exporter.php';
}

/**
 * DDWCWM_Users_CSV_Exporter Class.
 */
class DDWCWM_Users_CSV_Exporter extends \WC_CSV_Batch_Exporter {

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct();
	}

	/**
	 * Return an array of columns to export.
	 *
	 * @since  3.1.0
	 * @return array
	 */
	public function get_default_column_names() {
		return [
            'id'       => esc_html__( 'ID', 'ddwc-wallet-management' ),
            'username' => esc_html__( 'Username', 'ddwc-wallet-management' ),
            'email'    => esc_html__( 'Email', 'ddwc-wallet-management' ),
            'balance'  => esc_html__( 'Balance', 'ddwc-wallet-management' ),
        ];
	}

	/**
	 * Prepare data for export.
	 */
	public function prepare_data_to_export() {
        $per_page     = $this->get_limit();
        $current_page = $this->get_page();

        $off = ( $current_page - 1 ) * $per_page;

        $query = new \WP_User_Query( [
            'number'  => $per_page,
            'offset'  => $off,
            'order'   => 'ASC',
            'orderby' => 'ID',
            'fields'  => [ 'ID', 'user_login', 'user_email' ],
        ] );

        $users = $query->get_results();

        $this->total_rows  = $query->total_users;
		$this->row_data    = [];

        if ( ! empty( $users ) ) {
            $user_helper = new DDWCWM_Users_Helper();

            foreach ( $users as $user ) {
                $user_id = $user->ID;

                $balance = $user_helper->ddwcwm_get_user_wallet_balance( $user_id );

                $this->row_data[] = [
                    'id'       => $user_id,
                    'username' => $user->user_login,
                    'email'    => $user->user_email,
                    'balance'  => $balance,
                ];
            }
        } else {
            $this->total_rows = 0;
        }
    }
}
