<?php
/**
 * Email Notification Handler
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Includes;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCWM_Email_Notification_Handler' ) ) {
    /**
     * Email Notification Handler class.
     */
    class DDWCWM_Email_Notification_Handler extends \WC_Email {
        /**
         * Constructor.
         */
        public function __construct() {
            $this->id             = 'ddwcwm_notification';
            $this->title          = esc_html__( 'Wallet Notification', 'ddwc-wallet-management' );
            $this->heading        = esc_html__( 'Wallet Notification', 'ddwc-wallet-management' );
            $this->subject        = '[' . get_option( 'blogname' ) . '] ' . esc_html__( 'Wallet Notification', 'ddwc-wallet-management' );
            $this->description    = esc_html__( 'On using Wallet this mail is sent to user.', 'ddwc-wallet-management' );
            $this->template_html  = 'emails/wallet.php';
            $this->template_plain = 'emails/plain/wallet.php';
            $this->template_base  = DDWCWM_PLUGIN_FILE . '/templates/';
            $this->footer         = esc_html__( 'Thanks for choosing Wallet.', 'ddwc-wallet-management' );

			add_action( 'ddwcwm_mail_notification', [ $this, 'trigger' ] );

            // Call parent constructor
            parent::__construct();

            // Other settings
			$this->recipient = $this->get_option( 'recipient' );
			
			if ( ! $this->recipient ) {
				$this->recipient = get_option( 'admin_email' );
			}

            // Other settings
			$this->recipient = $this->get_option( 'recipient' );
			$this->subject   = $this->get_option( 'subject' );
			$this->heading   = $this->get_option( 'heading' );

			if ( ! $this->recipient ) {
				$this->recipient = get_option( 'admin_email' );
			}

            if ( ! $this->subject ) {
                $this->subject = '[' . get_option( 'blogname' ) . '] ' . esc_html__( 'Wallet Notification', 'ddwc-wallet-management' );
			}

            if ( ! $this->heading ) {
                $this->heading = esc_html__( 'Wallet Notification', 'ddwc-wallet-management' );
			}
        }

        /**
         * Trigger.
         *
         * @param array $data
         * @return void
         */
        public function trigger( $data ) {
			if ( empty( $data ) ) {
				return;
			} else {
                $this->display_name  = '';
                $this->email_message = $data[ 'message' ];
                if ( ! empty( $data[ 'email' ] ) ) {
                    $this->recipient = $data[ 'email' ];
                }

                if ( ! empty( $data[ 'display_name' ] ) ) {
                    $this->display_name = $data[ 'display_name' ];
                }
            }

            if ( $this->is_enabled() && $this->get_recipient() ) {
                $this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
            }
        }

        /**
         * Get content html.
         *
         * @access public
         * @return string
         */
        public function get_content_html() {
            return wc_get_template_html(
                $this->template_html, [
                    'email_heading'      => $this->get_heading(),
                    'email_message'      => $this->email_message,
                    'additional_content' => $this->get_additional_content(),
                    'display_name'       => $this->display_name,
                    'customer_email'     => $this->get_recipient(),
                    'blogname'           => $this->get_blogname(),
                    'sent_to_admin'      => false,
                    'plain_text'         => false,
                    'email'              => $this,
                ], '', $this->template_base
            );
        }

        /**
         * Get content plain.
         *
         * @access public
         * @return string
         */
        public function get_content_plain() {
            return wc_get_template_html(
                $this->template_plain, [
                    'email_heading'      => $this->get_heading(),
                    'email_message'      => $this->email_message,
                    'additional_content' => $this->get_additional_content(),
                    'display_name'       => $this->display_name,
                    'customer_email'     => $this->get_recipient(),
                    'blogname'           => $this->get_blogname(),
                    'sent_to_admin'      => false,
                    'plain_text'         => true,
                    'email'              => $this,
                ], '', $this->template_base
            );
        }
    }
}