<?php
/**
 * Configuration template class
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Templates\Admin\Configuration;

defined( 'ABSPATH' ) || exit();

if ( ! class_exists( 'DDWCWM_Configuration_Template' ) ) {
	/**
	 * Configuration template class
	 */
	class DDWCWM_Configuration_Template {
		/**
		 * Construct
		 */
		public function __construct() {
            if ( ! empty( $_GET[ 'settings-updated' ] ) && $_GET[ 'settings-updated' ] === 'true' ) {
                flush_rewrite_rules();
            }
			$this->ddwcwm_get_configuration_template();
        }

        /**
		 * Get Configuration Template function
		 *
		 * @return void
		 */
        public function ddwcwm_get_configuration_template() {

            global $ddwcwm_wallet;

            $license_activated = get_option( '_ddwcwm_license_activated' );
            $purchase_code     = get_option( '_ddwcwm_purchase_code' );

            if ( ! empty( $license_activated ) ) {
                $args = [
					'purchase_code' => $purchase_code,
					'user_agent'    => site_url(),
				];

				$response = wp_remote_post( 'https://devdiggers.com/wp-json/ddelv/v1/check-license', [
					'body' => json_encode( $args )
				] );

                $response = json_decode( wp_remote_retrieve_body( $response ) );

                if ( ! empty( $response ) && $response->success && ( $response->status == 'deactivated' || $response->status == 'deleted' ) ) {
                    delete_option( '_ddwcwm_license_activated' );
                    $license_activated = '';
                }

            }

            ?>
            <div class="wrap">
				<h1 class="wp-heading-inline"><?php esc_html_e( 'Configuration', 'ddwc-wallet-management' ); ?></h1>
				<hr class="wp-header-end" />
                <?php
                settings_errors();
                ?>
                <div class="ddwcwm-configuration-container">
                    <form action="options.php" method="POST">
                        <?php settings_fields( 'ddwcwm-configuration-fields' ); ?>
                        <h2 class="wp-heading-inline"><?php esc_html_e( 'General', 'ddwc-wallet-management' ); ?></h2>
                        <hr />
                        <table class="form-table">
                            <tbody>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-purchase-code'><?php esc_html_e( 'Activate License', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Enter your purchase code to activate your purchased license. You\'ll not able to use the plugin until you activate the license.', 'ddwc-wallet-management' ), true ); ?>

                                        <input type="text" name="_ddwcwm_purchase_code" class="regular-text <?php echo esc_attr( ! empty( $license_activated ) ? 'ddwcwm-hide' : '' ); ?>" id="ddwcwm-purchase-code" value="<?php echo esc_attr( $purchase_code ); ?>" placeholder="<?php esc_attr_e( 'Enter Purchase Code', 'ddwc-wallet-management' ); ?>" />

                                        <button class="button button-primary ddwcwm-verify-license <?php echo esc_attr( ! empty( $license_activated ) ? 'ddwcwm-hide' : '' ); ?>" data-action="activate" data-fetching="<?php esc_attr_e( 'Activating...', 'ddwc-wallet-management' ); ?>"><?php esc_html_e( 'Activate', 'ddwc-wallet-management' ); ?></button>

                                        <button class="button button-primary ddwcwm-verify-license <?php echo esc_attr( empty( $license_activated ) ? 'ddwcwm-hide' : '' ); ?>" data-action="deactivate" data-fetching="<?php esc_attr_e( 'Deactivating...', 'ddwc-wallet-management' ); ?>"><?php esc_html_e( 'Deactivate', 'ddwc-wallet-management' ); ?></button>

                                        <p class="description ddwcwm-margin-left-20"><a href="<?php echo esc_url( '//help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-' ); ?>" target="__blank"><?php esc_html_e( 'How to find your purchase code?', 'ddwc-wallet-management' ); ?></a></p>

                                        <div class="notice ddwcwm-hide">
                                            <p class="ddwcwp-license-status"></p>
                                        </div>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-enable'><?php esc_html_e( 'Enable/Disable', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Enable/Disable the module functionalities for every users.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="checkbox" value="yes" id="ddwcwm-enable" name="_ddwcwm_enabled" <?php checked( $ddwcwm_wallet[ 'enabled' ], 'yes' ); ?> />
                                        <label for='ddwcwm-enable'><?php esc_html_e( 'Enable WooCommerce Wallet Management', 'ddwc-wallet-management' ); ?></label>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-min-topup-limit'><?php esc_html_e( 'Min Topup Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the minimum topup limit for the wallet. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_min_topup_limit" class="regular-text" id="ddwcwm-min-topup-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'min_topup_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-max-topup-limit'><?php esc_html_e( 'Max Topup Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the maximum topup limit for the wallet. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_max_topup_limit" class="regular-text" id="ddwcwm-max-topup-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'max_topup_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-debit-limit-type'><?php esc_html_e( 'Debit Limit Type', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Select the wallet debit limit type.', 'ddwc-wallet-management' ), true ); ?>
                                        <select id="ddwcwm-debit-limit-type" name="_ddwcwm_debit_limit_type">
                                            <option value="fixed" <?php echo esc_attr( $ddwcwm_wallet[ 'debit_limit_type' ] == 'fixed' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Fixed', 'ddwc-wallet-management' ); ?></option>
                                            <option value="percentage" <?php echo esc_attr( $ddwcwm_wallet[ 'debit_limit_type' ] == 'percentage' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Percentage', 'ddwc-wallet-management' ); ?></option>
                                        </select>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-min-debit-limit'><?php esc_html_e( 'Min Debit Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the minimum debit limit for the wallet. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_min_debit_limit" class="regular-text" id="ddwcwm-min-debit-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'min_debit_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-max-debit-limit'><?php esc_html_e( 'Max Debit Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the maximum debit limit for the wallet. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_max_debit_limit" class="regular-text" id="ddwcwm-max-debit-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'max_debit_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-min-transfer-limit'><?php esc_html_e( 'Min Transfer Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the minimum transfer limit for the wallet for both send and request money. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_min_transfer_limit" class="regular-text" id="ddwcwm-min-transfer-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'min_transfer_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-max-transfer-limit'><?php esc_html_e( 'Max Transfer Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the maximum transfer limit for the wallet for both send and request money. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_max_transfer_limit" class="regular-text" id="ddwcwm-max-transfer-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'max_transfer_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-registration-credit'><?php esc_html_e( 'Registration Credit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the amount will be credited to customers if they register/signup on your store. If not entered, no credit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_registration_credit" class="regular-text" id="ddwcwm-registration-credit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'registration_credit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-topup-order-status'><?php esc_html_e( 'Wallet Topup Order Status', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Select the default wallet topup order status either default or completed.', 'ddwc-wallet-management' ), true ); ?>
                                        <select id="ddwcwm-topup-order-status" name="_ddwcwm_topup_order_status">
                                            <option value="default" <?php echo esc_attr( $ddwcwm_wallet[ 'topup_order_status' ] == 'default' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Default', 'ddwc-wallet-management' ); ?></option>
                                            <option value="completed" <?php echo esc_attr( $ddwcwm_wallet[ 'topup_order_status' ] == 'completed' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Completed', 'ddwc-wallet-management' ); ?></option>
                                        </select>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-partial-payments-enabled'><?php esc_html_e( 'Enable/Disable', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Enable/Disable partial payments i.e. customers can use their wallet as partial payment if they do not have enough balance and then use other payment methods to pay the rest.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="checkbox" value="yes" id="ddwcwm-partial-payments-enabled" name="_ddwcwm_partial_payments_enabled" <?php checked( $ddwcwm_wallet[ 'partial_payments_enabled' ], 'yes' ); ?> />
                                        <label for='ddwcwm-partial-payments-enabled'><?php esc_html_e( 'Enable/Disable Partial Payments', 'ddwc-wallet-management' ); ?></label>
                                    </td>
                                </tr>
                                <tr valign="top">
                                    <th scope="row" class="titledesc">
                                        <label for="ddwcwm-enabled-payment-gateways"><?php esc_html_e( 'Enabled Payment Gateways for Topup', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td>
                                        <?php echo wc_help_tip( esc_html__( 'Customers will only be able to topup with these payment gateways.', 'ddwc-wallet-management' ) ); ?>

                                        <select id="ddwcwm-enabled-payment-gateways" class="regular-text" name="_ddwcwm_enabled_payment_gateways[]" multiple>
                                        <?php
                                        $gateways = WC()->payment_gateways->get_available_payment_gateways();
                                        if( ! empty( $gateways ) ) {
                                            foreach( $gateways as $key => $gateway ) {
                                                if( $gateway->enabled == 'yes' && $gateway->id != 'ddwcwm_wallet' ) {
                                                    if ( in_array( $key, $ddwcwm_wallet[ 'enabled_payment_gateways' ] ) ) {
                                                        ?>
                                                        <option value="<?php echo esc_attr( $key ); ?>" selected="selected"><?php echo esc_html( $gateway->method_title ); ?></option>
                                                        <?php
                                                    } else {
                                                        ?>
                                                        <option value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $gateway->method_title ); ?></option>
                                                        <?php
                                                    }
                                                    ?>
                                                    <?php
                                                }
                                            }
                                        }
                                        ?>
                                        </select>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-configure-payment-gateway'><?php esc_html_e( 'Configure Payment Gateway', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Wallet Payment Gateway configuration page.', 'ddwc-wallet-management' ), true ); ?>
                                        <a href="<?php echo esc_url( admin_url( 'admin.php?page=wc-settings&tab=checkout&section=ddwcwm_wallet' ) ); ?>" class="button" target="__blank"><?php esc_html_e( 'Configure', 'ddwc-wallet-management' ); ?></a>
                                    </td>
                                </tr>

                                <?php do_action( 'ddwcwm_add_configuration_fields_before_withdrawal_fields' ); ?>
                            </tbody>
                        </table>
                        <h2 class="wp-heading-inline"><?php esc_html_e( 'OTP Verification', 'ddwc-wallet-management' ); ?></h2>
                        <hr />
                        <table class="form-table">
                            <tbody>
                                <tr valign="top">
                                    <th scope="row" class="titledesc">
                                        <label for="ddwcwm-enabled-otp-operations"><?php esc_html_e( 'Enabled OTP Verification via mail for the operations', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td>
                                        <?php echo wc_help_tip( esc_html__( 'Customers needs to do the OTP verification via mail in order to process the selected operations.', 'ddwc-wallet-management' ) ); ?>

                                        <select id="ddwcwm-enabled-otp-operations" class="regular-text" name="_ddwcwm_enabled_otp_operations[]" multiple>
                                            <option value="send" <?php echo esc_attr( in_array( 'send', $ddwcwm_wallet[ 'enabled_otp_operations' ] ) ? 'selected="selected"' : '' ) ?>><?php echo esc_html_e( 'Send', 'ddwc-wallet-management' ); ?></option>
                                            <option value="request" <?php echo esc_attr( in_array( 'request', $ddwcwm_wallet[ 'enabled_otp_operations' ] ) ? 'selected="selected"' : '' ) ?>><?php echo esc_html_e( 'Request', 'ddwc-wallet-management' ); ?></option>
                                            <option value="withdraw" <?php echo esc_attr( in_array( 'withdraw', $ddwcwm_wallet[ 'enabled_otp_operations' ] ) ? 'selected="selected"' : '' ) ?>><?php echo esc_html_e( 'Withdraw', 'ddwc-wallet-management' ); ?></option>
                                        </select>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-otp-expiry'><?php esc_html_e( 'OTP Expiry (in seconds)', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This will be the OTP expiration time in seconds. If not entered, no expiration will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_otp_expiry" class="regular-text" id="ddwcwm-otp-expiry" min="0" value="<?php echo esc_attr( $ddwcwm_wallet[ 'otp_expiry' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-otp-length'><?php esc_html_e( 'OTP digits length', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This will be the length of OTP digits. If not entered, 6 digits OTP will be generated.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_otp_length" class="regular-text" id="ddwcwm-otp-length" min="1" value="<?php echo esc_attr( $ddwcwm_wallet[ 'otp_length' ] ); ?>" />
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <h2 class="wp-heading-inline"><?php esc_html_e( 'Withdrawals', 'ddwc-wallet-management' ); ?></h2>
                        <hr />
                        <p class="description"><i><?php esc_html_e( 'Withdrawal requests will be procesed by admin manually.', 'ddwc-wallet-management' ); ?></i></p>
                        <table class="form-table">
                            <tbody>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-withdrawals-enabled'><?php esc_html_e( 'Enable/Disable', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Enable/Disable withdrawals funtionality for customers.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="checkbox" value="yes" id="ddwcwm-withdrawals-enabled" name="_ddwcwm_withdrawals_enabled" <?php checked( $ddwcwm_wallet[ 'withdrawals_enabled' ], 'yes' ); ?> />
                                        <label for='ddwcwm-withdrawals-enabled'><?php esc_html_e( 'Enable Withdrawals Funtionality for Customers.', 'ddwc-wallet-management' ); ?></label>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-withdraw-charges-type'><?php esc_html_e( 'Fee Charges Type', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the charge type which is applied in calculating charges amount when customers are withdrawing their wallet amount.', 'ddwc-wallet-management' ), true ); ?>
                                        <select id="ddwcwm-withdraw-charges-type" name="_ddwcwm_withdraw_charges_type">
                                            <option value="fixed" <?php echo esc_attr( $ddwcwm_wallet[ 'withdraw_charges_type' ] == 'fixed' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Fixed', 'ddwc-wallet-management' ); ?></option>
                                            <option value="percentage" <?php echo esc_attr( $ddwcwm_wallet[ 'withdraw_charges_type' ] == 'percentage' ? 'selected="selected"' : '' ); ?>><?php esc_html_e( 'Percentage', 'ddwc-wallet-management' ); ?></option>
                                        </select>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-withdraw-charges-amount'><?php esc_html_e( 'Fee Charges', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the amount which is gonna be charged to customers when they are withdrawing their wallet amount. If not entered, no charges will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_withdraw_charges_amount" class="regular-text" id="ddwcwm-withdraw-charges-amount" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'withdraw_charges_amount' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-min-withdrawal-limit'><?php esc_html_e( 'Min Withdrawal Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the minimum withdrawal limit for the wallet for both send and request money. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_min_withdrawal_limit" class="regular-text" id="ddwcwm-min-withdrawal-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'min_withdrawal_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-max-withdrawal-limit'><?php esc_html_e( 'Max Withdrawal Limit', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the maximum withdrawal limit for the wallet for both send and request money. If not entered, no limit will be there.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_max_withdrawal_limit" class="regular-text" id="ddwcwm-max-withdrawal-limit" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'max_withdrawal_limit' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <h2 class="wp-heading-inline"><?php esc_html_e( 'Referrals', 'ddwc-wallet-management' ); ?></h2>
                        <hr />
                        <p class="description"><i><?php esc_html_e( 'Both users can earn wallet funds on new successful registration.', 'ddwc-wallet-management' ); ?></i></p>
                        <table class="form-table">
                            <tbody>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-referrals-enabled'><?php esc_html_e( 'Enable/Disable', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Enable/Disable referrals funtionality for customers.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="checkbox" value="yes" id="ddwcwm-referrals-enabled" name="_ddwcwm_referrals_enabled" <?php checked( $ddwcwm_wallet[ 'referrals_enabled' ], 'yes' ); ?> />
                                        <label for='ddwcwm-referrals-enabled'><?php esc_html_e( 'Enable Referrals Funtionality for Customers to Earn.', 'ddwc-wallet-management' ); ?></label>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-referrals-earning-amount'><?php esc_html_e( 'Earning Amount', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the amount which both customers and new user can earn on successful registeration. If not entered, then there is no earning amount.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="_ddwcwm_referral_earning_amount" class="regular-text" id="ddwcwm-referrals-earning-amount" step="0.01" value="<?php echo esc_attr( $ddwcwm_wallet[ 'referral_earning_amount' ] ); ?>" />
                                        <strong><?php echo get_woocommerce_currency_symbol(); ?></strong>
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-referrals-email-content'><?php esc_html_e( 'Email Content', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the email content which is going to share to the user for the registration.', 'ddwc-wallet-management' ), true ); ?>
                                        <textarea name="_ddwcwm_referral_email_content" class="regular-text" id="ddwcwm-referrals-email-content" rows="4"><?php echo esc_html( $ddwcwm_wallet[ 'referral_email_content' ] ); ?></textarea>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <h2><?php esc_html_e( 'My Account Menu Configuration', 'ddwc-wallet-management' ); ?></h2>
                        <hr />
                        <table class="form-table">
                            <tbody>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-my-account-endpoint'><?php esc_html_e( 'Endpoint', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the endpoint used for the My Account menu which shows the wallet related information.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_my_account_endpoint" class="regular-text" id="ddwcwm-my-account-endpoint" value="<?php echo esc_attr( $ddwcwm_wallet[ 'my_account_endpoint' ] ); ?>" placeholder="<?php esc_attr_e( 'Default: ddwc-wallet-management', 'ddwc-wallet-management' ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-my-account-endpoint-title'><?php esc_html_e( 'Endpoint Title', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the endpoint title used for the My Account menu which shows the wallet related information.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_my_account_endpoint_title" class="regular-text" id="ddwcwm-my-account-endpoint-title" value="<?php echo esc_attr( $ddwcwm_wallet[ 'my_account_endpoint_title' ] ); ?>" placeholder="<?php esc_attr_e( 'Default: Product Share Discounts', 'ddwc-wallet-management' ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-enable-widgets-my-account-endpoint'><?php esc_html_e( 'Enable/Disable', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'Enable/Disable Sidebar Widgets', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="checkbox" value="yes" id="ddwcwm-enable-widgets-my-account-endpoint" name="_ddwcwm_enable_widgets_my_account_endpoint" <?php checked( $ddwcwm_wallet[ 'enable_widgets_my_account_endpoint' ], 'yes' ); ?> />
                                        <label for='ddwcwm-enable-widgets-my-account-endpoint'><?php esc_html_e( 'Enable Sidebar Widgets', 'ddwc-wallet-management' ); ?></label>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <h2 class="wp-heading-inline"><?php esc_html_e( 'Shortcodes', 'ddwc-wallet-management' ); ?></h2>
                        <hr />
                        <p class="description"><i><?php esc_html_e( 'All the shortcodes will work for the current logged in user.', 'ddwc-wallet-management' ); ?></i></p>
                        <table class="form-table">
                            <tbody>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-wallet-balance-only-shortcode'><?php esc_html_e( 'Wallet Balance', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the shortcode which will display the current user wallet balance.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_wallet_balance_only_shortcode" class="regular-text" id="ddwcwm-wallet-balance-only-shortcode" value="<?php echo esc_attr( $ddwcwm_wallet[ 'wallet_balance_only_shortcode' ] ); ?>" placeholder="<?php echo sprintf( esc_attr__( 'Default: %s', 'ddwc-wallet-management' ), '[ddwcwm_wallet_balance_shortcode]' ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-wallet-balance-shortcode'><?php esc_html_e( 'Wallet Balance Layout', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the shortcode which will display the wallet balance layout template.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_wallet_balance_shortcode" class="regular-text" id="ddwcwm-wallet-balance-shortcode" value="<?php echo esc_attr( $ddwcwm_wallet[ 'wallet_balance_shortcode' ] ); ?>" placeholder="<?php echo sprintf( esc_attr__( 'Default: %s', 'ddwc-wallet-management' ), '[ddwcwm_wallet_balance_layout_shortcode]' ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-wallet-opertions-shortcode'><?php esc_html_e( 'Wallet Operations', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the shortcode which will display the wallet operations like add, send, receive, withdraw & refer.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_wallet_operations_shortcode" class="regular-text" id="ddwcwm-wallet-opertions-shortcode" value="<?php echo esc_attr( $ddwcwm_wallet[ 'wallet_operations_shortcode' ] ); ?>" placeholder="<?php echo sprintf( esc_attr__( 'Default: %s', 'ddwc-wallet-management' ), '[ddwcwm_wallet_operations_shortcode]' ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-wallet-balance-opertions-shortcode'><?php esc_html_e( 'Wallet Balance & Operations Together', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the shortcode which will display the wallet balance & operations like add, send, receive or withdraw money together.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_wallet_balance_operations_shortcode" class="regular-text" id="ddwcwm-wallet-balance-opertions-shortcode" value="<?php echo esc_attr( $ddwcwm_wallet[ 'wallet_balance_operations_shortcode' ] ); ?>" placeholder="<?php echo sprintf( esc_attr__( 'Default: %s', 'ddwc-wallet-management' ), '[ddwcwm_wallet_balance_operations_shortcode]' ); ?>" />
                                    </td>
                                </tr>
                                <tr valign='top'>
                                    <th scope='row' class='titledesc'>
                                        <label for='ddwcwm-wallet-transactions-shortcode'><?php esc_html_e( 'Wallet Transactions', 'ddwc-wallet-management' ); ?></label>
                                    </th>
                                    <td class='forminp forminp-text'>
                                        <?php echo wc_help_tip( esc_html__( 'This is the shortcode which will display the wallet transactions.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="text" name="_ddwcwm_wallet_transactions_shortcode" class="regular-text" id="ddwcwm-wallet-transactions-shortcode" value="<?php echo esc_attr( $ddwcwm_wallet[ 'wallet_transactions_shortcode' ] ); ?>" placeholder="<?php echo sprintf( esc_attr__( 'Default: %s', 'ddwc-wallet-management' ), '[ddwcwm_wallet_transactions_shortcode]' ); ?>" />
                                    </td>
                                </tr>

                            </tbody>
                        </table>
                        <p class="description">
                            <i>
                                <?php
                                echo sprintf( esc_html__( 'If you really like our plugin, please leave us a %s rating, we\'ll really appreciate it.', 'ddwc-wallet-management' ), '<a href="//codecanyon.net/downloads" target="_blank" title="' . esc_attr__( 'Review', 'ddwc-wallet-management' ) . '" aria-label="' . esc_attr__( 'Review', 'ddwc-wallet-management' ) . '"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 192 32" height="10"><path d="M16 26.534L6.111 32 8 20.422l-8-8.2 11.056-1.688L16 0l4.944 10.534L32 12.223l-8 8.2L25.889 32zm40 0L46.111 32 48 20.422l-8-8.2 11.056-1.688L56 0l4.944 10.534L72 12.223l-8 8.2L65.889 32zm40 0L86.111 32 88 20.422l-8-8.2 11.056-1.688L96 0l4.944 10.534L112 12.223l-8 8.2L105.889 32zm40 0L126.111 32 128 20.422l-8-8.2 11.056-1.688L136 0l4.944 10.534L152 12.223l-8 8.2L145.889 32zm40 0L166.111 32 168 20.422l-8-8.2 11.056-1.688L176 0l4.944 10.534L192 12.223l-8 8.2L185.889 32z" fill="#F5A623" fill-rule="evenodd"/></svg></a>' )
                                ?>
                            </i>
                        </p>
                        <?php submit_button( esc_html__( 'Save Changes', 'ddwc-wallet-management' ) ); ?>
                    </form>
                </div>
            </div>
            <?php
        }
	}
}
