<?php
/**
 * Manual Credit/Debit template class
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

namespace DDWCWalletManagement\Templates\Admin\Manual_Credit_Debit;

use DDWCWalletManagement\Helper\Users;

defined( 'ABSPATH' ) || exit;

if ( ! class_exists( 'DDWCWM_Manual_Credit_Debit_Template' ) ) {
	/**
	 * Manual Credit/Debit template class
	 */
	class DDWCWM_Manual_Credit_Debit_Template {
		/**
		 * Construct
		 */
		public function __construct() {
			$this->ddwcwm_do_manual_credit_debit();
			$this->ddwcwm_get_manual_cedit_debit_template();
        }

        /**
		 * Do Manual Credit/Debit function
		 *
		 * @return void
		 */
        public function ddwcwm_do_manual_credit_debit() {

            if ( ! empty( $_POST[ 'ddwcwm_manual_transaction_submit' ] ) && ! empty( $_POST[ 'ddwcwm_manual_transaction_nonce' ] ) && wp_verify_nonce( $_POST[ 'ddwcwm_manual_transaction_nonce' ], 'ddwcwm_manual_transaction_nonce_action' ) ) {
                $user_helper = new Users\DDWCWM_Users_Helper();
                $user_helper->ddwcwm_update_user_wallet_amount( $_POST );
            }

        }

        /**
		 * Get Manual Credit/Debit Template function
		 *
		 * @return void
		 */
        public function ddwcwm_get_manual_cedit_debit_template() {
            ?>
			<div class="wrap">

                <h1 class="wp-heading-inline"><?php esc_html_e( 'Manual Credit/Debit', 'ddwc-wallet-management' ); ?></h1>
                <?php do_action( 'ddwcwm_add_after_heading_in_manual_credit_debit_page' ); ?>
                <hr class="wp-header-end" />

                <div class="ddwcwm-manual-transaction-container">
                    <form method="post" class="ddwcwm-manual-transaction-form">

                        <table class="form-table ddwcwm-manual-transaction-table">
                            <tbody>

                                <tr valign="middle">
                                    <th scope="row" class="titledesc">
                                        <label for="ddwcwm-users"><strong><?php esc_html_e( 'Select Users', 'ddwc-wallet-management' ); ?></strong></label>
                                    </th>
                                    <td class="forminp forminp-text">
                                        <?php echo wc_help_tip( esc_html__( 'Select users for which you want to perform this manual credit/debit.', 'ddwc-wallet-management' ), true ); ?>
                                        <select name="ddwcwm_users[]" class="ddwcwm-users regular-text" id="ddwcwm-users"  data-placeholder="<?php esc_attr_e( 'Search Users', 'ddwc-wallet-management' ); ?>" multiple></select>
                                    </td>
                                </tr>

                                <?php do_action( 'ddwcwm_add_fields_after_select_users_in_manual_credit_debit' ); ?>

                                <tr valign="middle">
                                    <th scope="row" class="titledesc">
                                        <label for="ddwcwm-wallet-amount"><strong><?php esc_html_e( 'Amount', 'ddwc-wallet-management' ); ?></strong></label>
                                    </th>
                                    <td class="forminp forminp-text">
                                        <?php echo wc_help_tip( esc_html__( 'Enter the amount you want to credit or debit.', 'ddwc-wallet-management' ), true ); ?>
                                        <input type="number" name="ddwcwm_wallet_amount" step="0.01" class="regular-text" id="ddwcwm-wallet-amount" min="0.01">
                                    </td>
                                </tr>

                                <tr valign="middle">
                                    <th scope="row" class="titledesc">
                                        <label for="ddwcwm-action"><strong><?php esc_html_e( 'Action', 'ddwc-wallet-management' ); ?></strong></label>
                                    </th>
                                    <td class="forminp forminp-text">
                                        <?php echo wc_help_tip( esc_html__( 'Select the transaction type for the selected users i.e. either credit or debit.', 'ddwc-wallet-management' ), true ); ?>
                                        <select name="ddwcwm_action_type" id="ddwcwm-action" title="action">
                                            <option value="credit"><?php esc_html_e( 'Credit', 'ddwc-wallet-management' ); ?></option>
                                            <option value="debit"><?php esc_html_e( 'Debit', 'ddwc-wallet-management' ); ?></option>
                                        </select>
                                    </td>
                                </tr>

                                <tr valign="top">
                                    <th scope="row" class="titledesc">
                                        <label for="ddwcwm-transaction-note"><strong><?php esc_html_e( 'Transaction Note', 'ddwc-wallet-management' ); ?></strong></label>
                                    </th>
                                    <td class="forminp forminp-text">
                                        <?php echo wc_help_tip( esc_html__( 'This is the transaction note which will be visible to the selected users for this transaction.', 'ddwc-wallet-management' ), true ); ?>
                                        <textarea rows="4" name="ddwcwm_transaction_note" class="regular-text" id="ddwcwm-transaction-note" title="<?php esc_attr_e( 'Transaction Note', 'ddwc-wallet-management' ); ?>"></textarea>
                                    </td>
                                </tr>

                                <?php do_action( 'ddwcwm_add_fields_in_end_in_manual_credit_debit' ); ?>

                            </tbody>
                        </table>

                        <p class="submit">
                            <?php 
                            wp_nonce_field( 'ddwcwm_manual_transaction_nonce_action', 'ddwcwm_manual_transaction_nonce' );
                            ?>
                            <input name="ddwcwm_manual_transaction_submit" id="ddwcwm-manual-transaction-submit" class="button-primary " type="submit" value="<?php esc_attr_e( 'Submit', 'ddwc-wallet-management' ); ?>">
                        </p>

                    </form>
                </div>
			</div>
            <?php
        }

	}
}
