<?php
/**
 * Wallet Transactions Shortcode
 *
 * @package WooCommerce Wallet Management
 * @version 1.0.0
 */

use DDWCWalletManagement\Helper\Users\DDWCWM_Users_Helper;
use DDWCWalletManagement\Helper\Transactions\DDWCWM_Transactions_Helper;

defined( 'ABSPATH' ) || exit();

global $ddwcwm_wallet;

$user_id = get_current_user_id();

$per_page = 10;

$current_page = ! empty( get_query_var( $ddwcwm_wallet[ 'my_account_endpoint' ] ) ) && is_numeric( get_query_var( $ddwcwm_wallet[ 'my_account_endpoint' ] ) ) ? get_query_var( $ddwcwm_wallet[ 'my_account_endpoint' ] ) : 1;

$offset = $current_page == 1 ? 0 : ( $current_page - 1 ) * $per_page;

$user_helper = new DDWCWM_Users_Helper();

$total_transactions_count = $user_helper->ddwcwm_get_user_total_transactions_count();
$transactions             = $user_helper->ddwcwm_get_user_transactions( $per_page, $offset );

?>
<div class="ddwcwm-transactions-wrapper">
    <h4><?php esc_html_e( 'Transactions', 'ddwc-wallet-management' ); ?></h4>
    <div class="ddwcwm-transactions-table-wrapper">
        <table class="ddwcwm-transactions-table">
            <thead>
                <tr>
                    <th><?php esc_html_e( 'ID', 'ddwc-wallet-management' ); ?></th>
                    <th><?php esc_html_e( 'Reference', 'ddwc-wallet-management' ); ?></th>
                    <th><?php esc_html_e( 'Amount', 'ddwc-wallet-management' ); ?></th>
                    <th><?php esc_html_e( 'Type', 'ddwc-wallet-management' ); ?></th>
                    <th><?php esc_html_e( 'Date', 'ddwc-wallet-management' ); ?></th>
                </tr>
            </thead>
            <tbody>
                <?php
                if ( ! empty( $transactions ) ) {
                    $my_account_permalink = get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );

                    foreach ( $transactions as $key => $transaction ) {
                        $order_id              = $transaction[ 'order_id' ];
                        $order_currency        = get_post_meta( $order_id, '_order_currency', true );
                        $order_currency        = apply_filters( 'ddwcwm_modify_transaction_currency', $order_currency, $order_id, $transaction );
                        $transaction_type      = $transaction[ 'type' ];
                        $transaction_reference = $transaction[ 'reference' ];

                        $transaction[ 'amount' ] = apply_filters( 'ddwcwm_modify_amount_to_multi_currency', $transaction[ 'amount' ] );

                        ob_start();
                        if ( $transaction_type == 'credit' || $transaction_reference == 'withdraw_cancelled' ) {
                            ?>
                            <span class="ddwcwm-credit">+<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                            <?php
                        } else if ( $transaction_reference == 'withdraw_completed' ) {
                            ?>
                            <span class="ddwcwm-complete"><?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                            <?php
                        } else if ( $transaction_type == 'transfer' ) {
                            $sender_id = $transaction[ 'sender_id' ];
                            if ( $user_id == $sender_id ) {
                                ?>
                                <span class="ddwcwm-debit">-<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                                <?php
                            } else {
                                ?>
                                <span class="ddwcwm-credit">+<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                                <?php
                            }
                            ?>
                            <?php
                        } else if ( $transaction_type == 'debit' || $transaction_type == 'withdraw' ) {
                            ?>
                            <span class="ddwcwm-debit">-<?php echo wc_price( $transaction[ 'amount' ], [ 'currency' => $order_currency ] ) ?></span>
                            <?php
                        }
                        $amount = ob_get_contents();
                        ob_end_clean();

                        ?>
                        <tr>
                            <td><a href="<?php echo esc_url( $my_account_permalink . $ddwcwm_wallet[ 'my_account_endpoint' ] . '/view/' . $transaction[ 'id' ] ); ?>"><?php echo esc_html( $transaction[ 'id' ] ); ?></a></td>
                            <td><?php echo esc_html( DDWCWM_Transactions_Helper::ddwcwm_get_transactions_translation( $transaction_reference ) ); ?></td>
                            <td><?php echo wp_kses_post( $amount ); ?></td>
                            <td><?php echo esc_html( DDWCWM_Transactions_Helper::ddwcwm_get_transactions_translation( $transaction_type ) ); ?></td>
                            <td><?php echo esc_html( date_i18n( 'F j, Y H:i:s', strtotime( $transaction[ 'date' ] ) ) ); ?></td>
                        </tr>
                        <?php
                    }
                } else {
                    ?>
                    <tr>
                        <td colspan="5"><center><?php esc_html_e( 'No transactions made yet.', 'ddwc-wallet-management' ); ?></center></td>
                    </tr>
                    <?php
                }
                ?>
            </tbody>
        </table>
    </div>
    <?php
    if ( 1 < $total_transactions_count ) {
        ?>
        <div class="woocommerce-pagination woocommerce-pagination--without-numbers woocommerce-Pagination">

            <?php
            if ( 1 !== $current_page && $current_page > 1 ) {
                ?>
                <a class="woocommerce-button woocommerce-button--previous woocommerce-Button woocommerce-Button--previous button" href="<?php echo esc_url( wc_get_endpoint_url( $ddwcwm_wallet[ 'my_account_endpoint' ], $current_page - 1 ) ); ?>"><?php esc_html_e( 'Previous', 'ddwc-wallet-management' ); ?></a>
                <?php
            }
            if ( ceil( $total_transactions_count / $per_page ) > $current_page ) {
                ?>
                <a class="woocommerce-button woocommerce-button--next woocommerce-Button woocommerce-Button--next button" href="<?php echo esc_url( wc_get_endpoint_url( $ddwcwm_wallet[ 'my_account_endpoint' ], $current_page + 1 ) ); ?>"><?php esc_html_e( 'Next', 'ddwc-wallet-management' ); ?></a>
                <?php
            }
            ?>
        </div>
        <?php
    }
    ?>
</div>